@@ -35,11 +35,12 @@ class Driver:
     port: int
 
     client: Optional[Client]
+    beater: Optional[Client]
     opstream: Optional[Iterator[str]]
     interval: Optional[Interval]
     token: str
 
-    def __init__(self, name: str, schema: dict, ops: list[str], host: str = 'localhost', port: int = 5000):
+    def __init__(self, name: str, schema: dict, ops: List[str], host: str = 'localhost', port: int = 5000):
         self.name = name
         self.validator = Validator(schema)
         self.ops = ops
@@ -47,6 +48,7 @@ class Driver:
         self.port = port
 
         self.client = None
+        self.beater = None
         self.opstream = None
         self.interval = None
 
@@ -54,6 +56,9 @@ class Driver:
         if self.client is None:
             self.client = Client(self.host, self.port)
 
+        if self.beater is None:
+            self.beater = Client(self.host, self.port)
+
         if self.opstream is None:
             schema = self.validator.schema
             self.token = self.client.register(self.name, schema, self.ops)
@@ -74,6 +79,7 @@ class Driver:
             self.client.close()
 
         self.client = None
+        self.beater = None
         self.opstream = None
         self.interval = None
 
@@ -83,8 +89,8 @@ class Driver:
             self.client.update(self.name, self.token, instance)
 
     def heartbeat(self):
-        if self.client is not None:
-            self.client.heartbeat(self.name, self.token)
+        if self.beater is not None:
+            self.beater.heartbeat(self.name, self.token)
 
     def __enter__(self):
         self.connect()
